@@ -17,6 +17,7 @@ from regexapp.core import enclose_string
 
 import yaml
 import re
+import platform
 
 
 __version__ = version
@@ -179,7 +180,7 @@ class Application:
     def __init__(self):
         self._base_title = 'Regex GUI'
         self.root = tk.Tk()
-        self.root.geometry('800x600+100+100')
+        self.root.geometry('900x600+100+100')
         self.root.minsize(200, 200)
         self.root.option_add('*tearOff', False)
         self.content = None
@@ -191,7 +192,7 @@ class Application:
         self.save_as_btn = None
         self.copy_text_btn = None
 
-        self.test_data = ''
+        self.test_data = None
 
         self.radio_line_or_block_btn_var = tk.StringVar()
         self.radio_line_or_block_btn_var.set('block')
@@ -352,6 +353,8 @@ class Application:
         def mouse_press(event):
             self.browser.open_new_tab(url_lbl.link)
 
+        is_macos = platform.system() == 'Darwin'
+
         about = tk.Toplevel(self.root)
         self.set_title(node=about, title='About')
         width, height = 400, 400
@@ -359,17 +362,27 @@ class Application:
         about.geometry('{}x{}+{}+{}'.format(width, height, x, y))
         about.resizable(False, False)
 
+        panedwindow = ttk.Panedwindow(about, orient=tk.VERTICAL)
+        panedwindow.pack(fill=tk.BOTH, expand=True, padx=8, pady=12)
+
         # company
+        frame = tk.Frame(panedwindow, width=380, height=20)
+        panedwindow.add(frame, weight=1)
+
         fmt = 'Regex GUI v{} ({} Edition)'
-        company_lbl = tk.Label(about, text=fmt.format(version, edition))
-        company_lbl.place(x=10, y=10)
+        company_lbl = tk.Label(frame, text=fmt.format(version, edition))
+        company_lbl.pack(side=tk.LEFT)
 
         # URL
+        frame = tk.Frame(panedwindow, width=380, height=20)
+        panedwindow.add(frame, weight=1)
+
         url = Data.repo_url
-        tk.Label(about, text='URL:').place(x=10, y=40)
-        url_lbl = tk.Label(about, text=url, fg='blue', font=('sans-serif', 10))
-        url_lbl.default_font = ('sans-serif', 10)
-        url_lbl.place(x=36, y=40)
+        tk.Label(frame, text='URL:').pack(side=tk.LEFT)
+        font_size = 12 if is_macos else 10
+        url_lbl = tk.Label(frame, text=url, fg='blue', font=('sans-serif', font_size))
+        url_lbl.default_font = ('sans-serif', font_size)
+        url_lbl.pack(side=tk.LEFT)
         url_lbl.link = url
 
         url_lbl.bind('<Enter>', mouse_over)
@@ -378,12 +391,15 @@ class Application:
 
         # license textbox
         lframe = ttk.LabelFrame(
-            about, height=280, width=380,
+            panedwindow, height=300, width=380,
             text=Data.license_name
         )
-        lframe.place(x=10, y=80)
-        txtbox = tk.Text(lframe, width=45, height=14, wrap='word')
-        txtbox.grid(row=0, column=0)
+        panedwindow.add(lframe, weight=7)
+
+        width = 49 if is_macos else 43
+        height = 19 if is_macos else 15
+        txtbox = tk.Text(lframe, width=width, height=height, wrap='word')
+        txtbox.grid(row=0, column=0, padx=5, pady=5)
         scrollbar = ttk.Scrollbar(lframe, orient=tk.VERTICAL, command=txtbox.yview)
         scrollbar.grid(row=0, column=1, sticky='nsew')
         txtbox.config(yscrollcommand=scrollbar.set)
@@ -391,17 +407,24 @@ class Application:
         txtbox.config(state=tk.DISABLED)
 
         # footer - copyright
-        footer = tk.Label(about, text=Data.copyright_text)
-        footer.place(x=10, y=360)
+        frame = tk.Frame(panedwindow, width=380, height=20)
+        panedwindow.add(frame, weight=1)
+
+        footer = tk.Label(frame, text=Data.copyright_text)
+        footer.pack(side=tk.LEFT)
 
         set_modal_dialog(about)
 
     def callback_preferences_settings(self):
         """Callback for Menu Preferences > Settings"""
 
+        is_macos = platform.system() == 'Darwin'
+        is_linux = platform.system() == 'Linux'
+
         settings = tk.Toplevel(self.root)
         self.set_title(node=settings, title='Settings')
-        width, height = 400, 430
+        width = 540 if is_macos else 490 if is_linux else 400
+        height = 370
         x, y = get_relative_center_location(self.root, width, height)
         settings.geometry('{}x{}+{}+{}'.format(width, height, x, y))
         settings.resizable(False, False)
@@ -411,70 +434,115 @@ class Application:
             settings, height=80, width=380,
             text='Pattern Arguments'
         )
-        lframe_pattern_args.place(x=10, y=10)
+        lframe_pattern_args.grid(row=0, column=0, padx=10, pady=10, sticky=tk.W)
 
         # arguments checkboxes
         lst = [
-            ['used_space', self.used_space_var, 5, 5],
-            ['ignore_case', self.ignore_case_var, 120, 5],
-            ['prepended_ws', self.prepended_ws_var, 5, 30],
-            ['appended_ws', self.appended_ws_var, 120, 30]
+            ['used_space', self.used_space_var, 0, 0],
+            ['ignore_case', self.ignore_case_var, 0, 1],
+            ['prepended_ws', self.prepended_ws_var, 1, 0],
+            ['appended_ws', self.appended_ws_var, 1, 1]
         ]
-        for text, variable, x, y in lst:
-            ttk.Checkbutton(lframe_pattern_args, text=text, variable=variable,
-                            onvalue=True, offvalue=False).place(x=x, y=y)
+        for text, variable, row, column in lst:
+            tk.Checkbutton(
+                lframe_pattern_args, text=text, variable=variable,
+                onvalue=True, offvalue=False
+            ).grid(row=row, column=column, padx=2, pady=2, sticky=tk.W)
 
         # Settings - Builder Arguments
         lframe_builder_args = ttk.LabelFrame(
-            settings, height=210, width=380,
+            settings, height=280, width=380,
             text='Builder Arguments'
         )
-        lframe_builder_args.place(x=10, y=95)
+        # lframe_builder_args.place(x=10, y=95)
+        lframe_builder_args.grid(row=1, column=0, padx=10, pady=(0, 10), sticky=tk.W)
 
-        ttk.Label(lframe_builder_args, text='max_words').place(x=5, y=5)
-        ttk.Entry(lframe_builder_args, width=5,
-                  textvariable=self.max_words_var).place(x=88, y=5)
+        pady = 0 if is_macos else 3
 
-        ttk.Checkbutton(lframe_builder_args, text='is_minimal',
-                        variable=self.is_minimal_var,
-                        onvalue=True, offvalue=False).place(x=200, y=5)
+        ttk.Label(
+            lframe_builder_args, text='max_words'
+        ).grid(row=0, column=0, columnspan=2, padx=2, pady=(5, pady), sticky=tk.W)
 
-        ttk.Label(lframe_builder_args, text='test_name').place(x=5, y=30)
-        ttk.Entry(lframe_builder_args, width=45,
-                  textvariable=self.test_name_var).place(x=88, y=30)
+        ttk.Entry(
+            lframe_builder_args, width=5, textvariable=self.max_words_var
+        ).grid(row=0, column=2, padx=2, pady=(5, pady), sticky=tk.W)
 
-        ttk.Label(lframe_builder_args, text='test_cls_name').place(x=5, y=55)
-        ttk.Entry(lframe_builder_args, width=45,
-                  textvariable=self.test_cls_name_var).place(x=88, y=55)
+        tk.Checkbutton(
+            lframe_builder_args, text='is_minimal',
+            variable=self.is_minimal_var, onvalue=True, offvalue=False
+        ).grid(row=0, column=3, columnspan=3, padx=2, pady=(5, pady), sticky=tk.W)
 
-        ttk.Label(lframe_builder_args, text='filename').place(x=5, y=80)
-        ttk.Entry(lframe_builder_args, width=45,
-                  textvariable=self.filename_var).place(x=88, y=80)
+        ttk.Label(
+            lframe_builder_args, text='test_name'
+        ).grid(row=1, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
+        ttk.Entry(
+            lframe_builder_args, width=45,
+            textvariable=self.test_name_var
+        ).grid(row=1, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(lframe_builder_args, text='author').place(x=5, y=105)
-        ttk.Entry(lframe_builder_args, width=45,
-                  textvariable=self.author_var).place(x=88, y=105)
+        ttk.Label(
+            lframe_builder_args, text='test_cls_name'
+        ).grid(row=2, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
+        ttk.Entry(
+            lframe_builder_args, width=45,
+            textvariable=self.test_cls_name_var
+        ).grid(row=2, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(lframe_builder_args, text='email').place(x=5, y=130)
-        ttk.Entry(lframe_builder_args, width=45,
-                  textvariable=self.email_var).place(x=88, y=130)
+        ttk.Label(
+            lframe_builder_args, text='filename'
+        ).grid(row=3, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
+        ttk.Entry(
+            lframe_builder_args, width=45,
+            textvariable=self.filename_var
+        ).grid(row=3, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Label(lframe_builder_args, text='company').place(x=5, y=155)
-        ttk.Entry(lframe_builder_args, width=45,
-                  textvariable=self.company_var).place(x=88, y=155)
+        ttk.Label(
+            lframe_builder_args, text='author'
+        ).grid(row=4, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
+        ttk.Entry(
+            lframe_builder_args, width=45,
+            textvariable=self.author_var
+        ).grid(row=4, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Button(settings, text='Default',
-                   command=lambda: self.set_default_setting(),
-                   width=8).place(x=270, y=395)
+        ttk.Label(
+            lframe_builder_args, text='email'
+        ).grid(row=5, column=0, columnspan=2, padx=2, pady=pady, sticky=tk.W)
+        ttk.Entry(
+            lframe_builder_args, width=45,
+            textvariable=self.email_var
+        ).grid(row=5, column=2, columnspan=4, padx=2, pady=pady, sticky=tk.W)
 
-        ttk.Button(settings, text='OK',
-                   command=lambda: settings.destroy(),
-                   width=8).place(x=332, y=395)
+        ttk.Label(
+            lframe_builder_args, text='company'
+        ).grid(row=6, column=0, columnspan=2, padx=2, pady=(pady, 10), sticky=tk.W)
+        ttk.Entry(
+            lframe_builder_args, width=45,
+            textvariable=self.company_var
+        ).grid(row=6, column=2, columnspan=4, padx=2, pady=(pady, 10), sticky=tk.W)
+
+        # OK and Default buttons
+        frame = tk.Frame(
+            settings, height=20, width=380
+        )
+        frame.grid(row=2, column=0, padx=10, pady=10, sticky=tk.E+tk.S)
+
+        ttk.Button(
+            frame, text='Default',
+            command=lambda: self.set_default_setting(),
+        ).grid(row=0, column=6, padx=1, pady=1, sticky=tk.E)
+
+        ttk.Button(
+            frame, text='OK',
+            command=lambda: settings.destroy(),
+        ).grid(row=0, column=7, padx=1, pady=1, sticky=tk.E)
 
         set_modal_dialog(settings)
 
     def callback_preferences_system_reference(self):
         """Callback for Menu Preferences > System References"""
+
+        is_macos = platform.system() == 'Darwin'
+
         sys_ref = tk.Toplevel(self.root)
         self.set_title(node=sys_ref, title='System References')
         width, height = 600, 500
@@ -511,9 +579,10 @@ class Application:
             state=tk.DISABLED
         )
 
+        padx, pady = (0, 0) if is_macos else (2, 2)
         ttk.Button(sys_ref, text='OK',
-                   command=lambda: sys_ref.destroy(),
-                   width=8).pack(side=tk.RIGHT)
+                   command=lambda: sys_ref.destroy()
+                   ).pack(side=tk.RIGHT, padx=padx, pady=pady)
 
         set_modal_dialog(sys_ref)
 
@@ -565,6 +634,8 @@ class Application:
             node.delete("1.0", "end")
             node.insert(tk.INSERT, new_content_)
 
+        is_macos = platform.system() == 'Darwin'
+
         fn = REF.user_ref_loc
         file_obj = Path(fn)
         if not file_obj.exists():
@@ -613,25 +684,26 @@ class Application:
             yscrollcommand=vscrollbar.set, xscrollcommand=hscrollbar.set,
         )
 
-        ttk.Button(
-            user_ref, text='Save', command=lambda: save(textarea), width=8
-        ).pack(side=tk.RIGHT)
+        padx, pady = (0, 0) if is_macos else (2, 2)
 
         ttk.Button(
-            user_ref, text='Close', command=lambda: user_ref.destroy(), width=8
-        ).pack(side=tk.RIGHT)
+            user_ref, text='Save', command=lambda: save(textarea)
+        ).pack(side=tk.RIGHT, padx=padx, pady=pady)
 
-        tk.Label(user_ref, text='Name:').pack(side=tk.LEFT)
+        ttk.Button(
+            user_ref, text='Close', command=lambda: user_ref.destroy()
+        ).pack(side=tk.RIGHT, padx=padx, pady=pady)
+
+        tk.Label(user_ref, text='Name:').pack(side=tk.LEFT, padx=padx, pady=pady)
 
         ttk.Entry(
             user_ref, width=25, textvariable=self.new_pattern_name_var
-        ).pack(side=tk.LEFT)
+        ).pack(side=tk.LEFT, padx=padx, pady=pady)
 
         ttk.Button(
             user_ref, text='Insert',
             command=lambda: insert(self.new_pattern_name_var, textarea),
-            width=8
-        ).pack(side=tk.LEFT)
+        ).pack(side=tk.LEFT, padx=padx, pady=pady)
 
         set_modal_dialog(user_ref)
 
@@ -676,7 +748,7 @@ class Application:
     def build_frame(self):
         """Build layout for regex GUI."""
         self.panedwindow = ttk.Panedwindow(self.root, orient=tk.VERTICAL)
-        self.panedwindow.pack(fill=tk.BOTH, expand=True)
+        self.panedwindow.pack(fill=tk.BOTH, expand=True, padx=2, pady=2)
 
         self.text_frame = ttk.Frame(
             self.panedwindow, width=600, height=300, relief=tk.RIDGE
@@ -759,7 +831,7 @@ class Application:
             self.result_textarea.delete("1.0", "end")
             self.save_as_btn.config(state=tk.DISABLED)
             self.copy_text_btn.config(state=tk.DISABLED)
-            self.test_data = ''
+            self.test_data = None
             # self.root.clipboard_clear()
             self.set_title()
 
@@ -786,6 +858,15 @@ class Application:
                 )
 
         def callback_snippet_btn():
+            if self.test_data is None:
+                create_msgbox(
+                    title='No Test Data',
+                    error=("Can NOT build Python test script without "
+                           "test data.\nPlease use Open or Paste button "
+                           "to load test data")
+                )
+                return
+
             user_data = Application.get_textarea(self.textarea)
             if not user_data:
                 create_msgbox(
@@ -810,6 +891,15 @@ class Application:
                 create_msgbox(title='RegexBuilder Error', error=error)
 
         def callback_unittest_btn():
+            if self.test_data is None:
+                create_msgbox(
+                    title='No Test Data',
+                    error=("Can NOT build Python Unittest script without "
+                           "test data.\nPlease use Open or Paste button "
+                           "to load test data")
+                )
+                return
+
             user_data = Application.get_textarea(self.textarea)
             if not user_data:
                 create_msgbox(
@@ -834,6 +924,15 @@ class Application:
                 create_msgbox(title='RegexBuilder Error', error=error)
 
         def callback_pytest_btn():
+            if self.test_data is None:
+                create_msgbox(
+                    title='No Test Data',
+                    error=("Can NOT build Python Pytest script without "
+                           "test data.\nPlease use Open or Paste button "
+                           "to load test data")
+                )
+                return
+
             user_data = Application.get_textarea(self.textarea)
             if not user_data:
                 create_msgbox(
@@ -869,66 +968,66 @@ class Application:
             variable=self.radio_line_or_block_btn_var,
             value='line'
         )
-        self.line_radio_btn.place(x=10, y=10)
+        self.line_radio_btn.grid(row=0, column=0, padx=(4, 0))
 
         self.block_radio_btn = ttk.Radiobutton(
             self.entry_frame, text='block',
             variable=self.radio_line_or_block_btn_var,
             value='block'
         )
-        self.block_radio_btn.place(x=55, y=10)
+        self.block_radio_btn.grid(row=0, column=1, padx=2)
 
         # open button
         open_file_btn = ttk.Button(self.entry_frame, text='Open',
-                                   command=self.callback_file_open, width=6)
-        open_file_btn.place(x=110, y=10)
+                                   command=self.callback_file_open)
+        open_file_btn.grid(row=0, column=2, pady=2)
 
         # Save As button
         self.save_as_btn = ttk.Button(self.entry_frame, text='Save As',
-                                      command=callback_save_as_btn, width=7)
-        self.save_as_btn.place(x=155, y=10)
+                                      command=callback_save_as_btn)
+        self.save_as_btn.grid(row=0, column=3)
         self.save_as_btn.config(state=tk.DISABLED)
 
         # copy button
         self.copy_text_btn = ttk.Button(self.entry_frame, text='Copy',
-                                        command=callback_copy_text_btn, width=6)
-        self.copy_text_btn.place(x=206, y=10)
+                                        command=callback_copy_text_btn)
+        self.copy_text_btn.grid(row=0, column=4)
         self.copy_text_btn.config(state=tk.DISABLED)
 
         # paste button
         paste_text_btn = ttk.Button(self.entry_frame, text='Paste',
-                                    command=callback_paste_text_btn, width=6)
-        paste_text_btn.place(x=251, y=10)
+                                    command=callback_paste_text_btn)
+        paste_text_btn.grid(row=0, column=5)
 
         # clear button
         clear_text_btn = ttk.Button(self.entry_frame, text='Clear',
-                                    command=callback_clear_text_btn, width=6)
-        clear_text_btn.place(x=296, y=10)
+                                    command=callback_clear_text_btn)
+        clear_text_btn.grid(row=0, column=6)
 
         # build button
         build_btn = ttk.Button(self.entry_frame, text='Build',
-                               command=callback_build_btn, width=6)
-        build_btn.place(x=341, y=10)
+                               command=callback_build_btn)
+        build_btn.grid(row=0, column=7)
 
         # snippet button
         snippet_btn = ttk.Button(self.entry_frame, text='Snippet',
-                                 command=callback_snippet_btn, width=7)
-        snippet_btn.place(x=386, y=10)
+                                 command=callback_snippet_btn)
+        snippet_btn.grid(row=0, column=8)
 
         # unittest button
         unittest_btn = ttk.Button(self.entry_frame, text='Unittest',
-                                  command=callback_unittest_btn, width=7)
-        unittest_btn.place(x=437, y=10)
+                                  command=callback_unittest_btn)
+        unittest_btn.grid(row=0, column=9)
 
         # pytest button
         pytest_btn = ttk.Button(self.entry_frame, text='Pytest',
-                                command=callback_pytest_btn, width=6)
-        pytest_btn.place(x=488, y=10)
+                                command=callback_pytest_btn)
+        pytest_btn.grid(row=0, column=10)
 
         # Robotframework button
         # rf_btn = ttk.Button(self.entry_frame, text='RF',
         #                     command=callback_rf_btn, width=4)
-        # rf_btn.place(x=533, y=10)
+        # rf_btn.grid(row=0, column=11)
 
     def build_result(self):
         """Build result text"""
